@@ -12,5 +12,5 @@ class ChangeReloader(StatReload):
         flag = super().should_restart()
         if flag:
             logger.warning("pre-reloading! sending shutdown request...")
-            requests.get(f"http://localhost:{self.config.port}/shutdown", timeout=1)
+            requests.get(f"http://localhost:{self.config.port}/api/shutdown", timeout=1)
         return flag
